@@ -9,6 +9,7 @@
 )]
 #![deny(clippy::all)]
 #![allow(clippy::module_name_repetitions, clippy::no_effect_underscore_binding)]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![cfg_attr(not(test), warn(clippy::panic_in_result_fn))]
 //! A simple database system that allows the use of multiple different backends.
@@ -38,5 +39,4 @@ pub type Gateway<B> = Starchart<B>;
 
 /// The helper derive macro for easily implementing [`IndexEntry`].
 #[cfg(feature = "derive")]
-#[cfg_attr(docsrs, doc(cfg(feature = "derive")))]
 pub use starchart_derive::IndexEntry;
